@@ -1,7 +1,37 @@
 #
-# bio/db/embl/sptr.rb - SwissProt and TrEMBL database class
+# = bio/db/embl/sptr.rb - UniProt/SwissProt and TrEMBL database class
 # 
-#   Copyright (C) 2001-2003 Mitsuteru C. Nakao <n@bioruby.org>
+# Copyright::   Copyright (C) 2001-2005 Mitsuteru C. Nakao <n@bioruby.org>
+# License::     LGPL
+#
+# $Id: sptr.rb,v 1.30 2006/01/28 06:40:38 nakao Exp $
+#
+# == Description
+# 
+# Shared methods for UniProtKB/SwissProt and TrEMBL classes.
+#
+# See the SWISS-PROT document file SPECLIST.TXT or UniProtKB/SwissProt 
+# user manual.
+# 
+# == Examples
+#
+#   str = File.read("p53_human.swiss")
+#   obj = Bio::SPTR.new(str)
+#   obj.entry_id #=> "P53_HUMAN"
+# 
+# == References
+# 
+# * Swiss-Prot Protein knowledgebase. TrEMBL Computer-annotated supplement 
+#   to Swiss-Prot	
+#   http://au.expasy.org/sprot/
+#
+# * UniProt
+#   http://uniprot.org/
+#
+# * The UniProtKB/SwissProt/TrEMBL User Manual
+#   http://www.expasy.org/sprot/userman.html
+#
+#--
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -17,37 +47,36 @@
 #  License along with this library; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 #
-#  $Id: sptr.rb,v 1.24 2005/08/08 06:41:13 nakao Exp $
+#++
 #
 
 require 'bio/db'
+require 'bio/db/embl/common'
 
 module Bio
 
+# Parser class for UniProtKB/SwissProt and TrEMBL database entry.
 class SPTR < EMBLDB
-
-  require 'bio/db/embl/common'
-  include Bio::EMBL::Common
+  include Bio::EMBLDB::Common
     
-
-  # ID Line
-  #
-  # "ID  #{ENTRY_NAME} #{DATA_CLASS}; #{MOLECULE_TYPE}; #{SEQUENCE_LENGTH}."
-  #
-  #   ENTRY_NAME = "#{X}_#{Y}"
-  #     X =~ /[A-Z0-9]{1,4}/ # The protein name.
-  #     Y =~ /[A-Z0-9]{1,5}/ # The biological source of the protein.
-  #   MOLECULE_TYPE = 'PRT' =~ /\w{3}/ 
-  #   SEQUENCE_LENGTH =~ /\d+ AA/
-  #
-  # See also the SWISS-PROT dicument file SPECLIST.TXT.
-  #
-
   @@entry_regrexp = /[A-Z0-9]{1,4}_[A-Z0-9]{1,5}/
   @@data_class = ["STANDARD", "PRELIMINARY"]
 
-  # Bio::SPTR#id_line -> hsh
-  # Bio::SPTR#id_line(key) -> str or int
+  
+  # returns a Hash of the ID line.
+  #
+  # returns a content (Int or String) of the ID line by a given key.
+  # Hash keys: ['ENTRY_NAME', 'DATA_CLASS', 'MODECULE_TYPE', 'SEQUENCE_LENGTH']
+  #
+  # === ID Line
+  #   ID   P53_HUMAN      STANDARD;      PRT;   393 AA.
+  #   #"ID  #{ENTRY_NAME} #{DATA_CLASS}; #{MOLECULE_TYPE}; #{SEQUENCE_LENGTH}."
+  #
+  # === Examples
+  #   obj.id_line  #=> {"ENTRY_NAME"=>"P53_HUMAN", "DATA_CLASS"=>"STANDARD", "SEQUENCE_LENGTH"=>393, "MOLECULE_TYPE"=>"PRT"}
+  #
+  #   obj.id_line('ENTRY_NAME') #=> "P53_HUMAN"
+  #
   def id_line(key = nil)
     unless @data['ID']
       tmp = Hash.new
@@ -60,57 +89,60 @@ class SPTR < EMBLDB
     end
 
     if key
-      @data['ID'][key]	# String/Int
+      @data['ID'][key] # String/Int
     else
-      @data['ID']		# Hash
+      @data['ID']      # Hash
     end
   end
 
+
+
+  # returns a ENTRY_NAME in the ID line. 
   #
-  def entry
+  def entry_id
     id_line('ENTRY_NAME')
   end
-  alias entry_name entry
-  alias entry_id entry
+  alias entry_name entry_id
+  alias entry entry_id
 
+
+  # returns a MOLECULE_TYPE in the ID line.
   #
+  # A short-cut for Bio::SPTR#id_line('MOLECULE_TYPE').
   def molecule
     id_line('MOLECULE_TYPE')
   end
   alias molecule_type molecule
 
-  #
+
+  # returns a SEQUENCE_LENGTH in the ID line.
+  # 
+  # A short-cut for Bio::SPTR#id_line('SEQUENCE_LENGHT').
   def sequence_length
     id_line('SEQUENCE_LENGTH')
   end
   alias aalen sequence_length
 
 
-  # AC Line
-  #
-  # "AC   A12345; B23456;"
-  #
-  #   AC [AC1;]+
-  #
-  #   Accession numbers format:
-  #   1       2     3          4          5          6
-  #   [O,P,Q] [0-9] [A-Z, 0-9] [A-Z, 0-9] [A-Z, 0-9] [0-9]
-  #
-  # Bio::SPTR#ac  -> ary
-  #          #accessions  -> ary
-  #          #accession  -> accessions.first
-
+  # Bio::EMBLDB::Common#ac  -> ary
+  #                  #accessions  -> ary
+  #                  #accession  -> String (accessions.first)
   @@ac_regrexp = /[OPQ][0-9][A-Z0-9]{3}[0-9]/ 
 
 
-  # DT Line; date (3/entry)
-  # DT DD-MMM-YYY (rel. NN, Created)
-  # DT DD-MMM-YYY (rel. NN, Last sequence update)
-  # DT DD-MMM-YYY (rel. NN, Last annotation update)
+
+  # returns a Hash of information in the DT lines.
+  #  hash keys: 
+  #    ['created', 'sequence', 'annotation']
+  #  also Symbols acceptable (ASAP):
+  #    [:created, :sequence, :annotation]
   #
-  # Bio::SPTR#dt  -> Hash
-  # Bio::SPTR#dt(key)  -> String
-  # key = (created|sequence|annotation)
+  # returns a String of information in the DT lines by a given key..
+  #
+  # === DT Line; date (3/entry)
+  #   DT DD-MMM-YYY (rel. NN, Created)
+  #   DT DD-MMM-YYY (rel. NN, Last sequence update)
+  #   DT DD-MMM-YYY (rel. NN, Last annotation update)
   def dt(key = nil)
     unless @data['DT']
       tmp = Hash.new
@@ -129,14 +161,14 @@ class SPTR < EMBLDB
   end
 
 
-  # DE Line; description (>=1)
-  # "DE #{OFFICIAL_NAME} (#{SYNONYM})"
-  # "DE #{OFFICIAL_NAME} (#{SYNONYM}) [CONTEINS: #1; #2]."
-  # OFFICIAL_NAME  1/entry
-  # SYNONYM        >=0
-  # CONTEINS       >=0
-  #
-  # Returns the proposed official name of the protein
+  # returns the proposed official name of the protein.
+  # 
+  # === DE Line; description (>=1)
+  #  "DE #{OFFICIAL_NAME} (#{SYNONYM})"
+  #  "DE #{OFFICIAL_NAME} (#{SYNONYM}) [CONTEINS: #1; #2]."
+  #  OFFICIAL_NAME  1/entry
+  #  SYNONYM        >=0
+  #  CONTEINS       >=0
   def protein_name
     name = ""
     if de_line = fetch('DE') then
@@ -146,8 +178,11 @@ class SPTR < EMBLDB
     end
     return name
   end
-  # synonyms are each placed in () following the official name on the DE line
-  # Returns an array of synonyms (unofficial names)
+
+
+  # returns an array of synonyms (unofficial names).
+  #
+  # synonyms are each placed in () following the official name on the DE line.
   def synonyms
     ary = Array.new
     if de_line = fetch('DE') then
@@ -162,7 +197,22 @@ class SPTR < EMBLDB
   end
 
 
-  # GN Line: Gene name(s) (>=0, optional)
+  # returns gene names in the GN line.
+  #
+  # New UniProt/SwissProt format:
+  # * Bio::SPTR#gn -> [ <gene record>* ]
+  # where <gene record> is:
+  #                    { :name => '...', 
+  #                      :synonyms => [ 's1', 's2', ... ],
+  #                      :loci   => [ 'l1', 'l2', ... ],
+  #                      :orfs     => [ 'o1', 'o2', ... ] 
+  #                    }
+  #
+  # Old format:
+  # * Bio::SPTR#gn -> Array      # AND 
+  # * Bio::SPTR#gn[0] -> Array   # OR
+  #
+  # === GN Line: Gene name(s) (>=0, optional)
   def gn
     return @data['GN'] if @data['GN']
 
@@ -174,17 +224,17 @@ class SPTR < EMBLDB
     end
   end
 
-  # GN Line: Gene name(s) (>=0, optional)
-  # GN   HNS OR DRDX OR OSMZ OR BGLY.
-  # GN   CECA1 AND CECA2.
-  # GN   CECA1 AND (HOGE OR FUGA).
+  # returns contents in the old style GN line.
+  # === GN Line: Gene name(s) (>=0, optional)
+  #  GN   HNS OR DRDX OR OSMZ OR BGLY.
+  #  GN   CECA1 AND CECA2.
+  #  GN   CECA1 AND (HOGE OR FUGA).
   #
-  # GN NAME1 [(AND|OR) NAME]+.
+  #  GN NAME1 [(AND|OR) NAME]+.
   #
   # Bio::SPTR#gn -> Array      # AND 
   #          #gn[0] -> Array   # OR
   #          #gene_names -> Array
-  #
   def gn_old_parser
     names = Array.new
     if get('GN').size > 0
@@ -199,15 +249,13 @@ class SPTR < EMBLDB
   end
   private :gn_old_parser
 
-
+  # returns contents in the structured GN line.
   # The new format of the GN line is:
-  # GN   Name=; Synonyms=[, ...]; OrderedLocusNames=[, ...];
-  # GN   ORFNames=[, ...];
-  # 
-  # GN   and
+  #  GN   Name=; Synonyms=[, ...]; OrderedLocusNames=[, ...];
+  #  GN   ORFNames=[, ...];
   #
-  # Bio::SPTR#gn -> [ <gene record>* ]
-  #   where <gene record> is:
+  # * Bio::SPTR#gn -> [ <gene record>* ]
+  # where <gene record> is:
   #                    { :name => '...', 
   #                      :synonyms => [ 's1', 's2', ... ],
   #                      :loci   => [ 'l1', 'l2', ... ],
@@ -238,7 +286,7 @@ class SPTR < EMBLDB
   private :gn_uniprot_parser
 
 
-  # Bio::SPTR#gene_names -> [String]
+  # returns a Array of gene names in the GN line.
   def gene_names
     gn # set @data['GN'] if it hasn't been already done
     if @data['GN'].first.class == Hash then
@@ -249,29 +297,27 @@ class SPTR < EMBLDB
   end
 
 
-  # Bio::SPTR#gene_name -> String
-  #
+  # returns a String of the first gene name in the GN line.
   def gene_name
     gene_names.first
   end
 
 
-  # OS Line; organism species (>=1)
-  # "OS   Genus species (name)."
-  # "OS   Genus species (name0) (name1)."
-  # "OS   Genus species (name0) (name1)."
-  # "OS   Genus species (name0), G s0 (name0), and G s (name0) (name1)."
-  # "OS   Homo sapiens (Human), and Rarrus norveticus (Rat)"
-  #
-  # Bio::EMBLDB#os  -> Array of Hash
-  # [{'name'=>'(Human)', 'os'=>'Homo sapiens'}, 
-  #  {'name'=>'(Rat)', 'os'=>'Rattus norveticus'}]
-  # Bio::SPTR#os[0]['name'] => "(Human)"
-  # Bio::EPTR#os[0] => {'name'=>"(Human)", 'os'=>'Homo sapiens'}
-  # Bio::EPTR#os(0) => "Homo sapiens (Human)"
-  #
-  # Bio::SPTR#os -> Array of Hash
-  # Bio::SPTR#os(num) -> String
+  # returns a Array of Hashs or a String of the OS line when a key given.
+  # * Bio::EMBLDB#os  -> Array
+  #  [{'name' => '(Human)', 'os' => 'Homo sapiens'}, 
+  #   {'name' => '(Rat)', 'os' => 'Rattus norveticus'}]
+  # * Bio::EPTR#os[0] -> Hash 
+  #  {'name' => "(Human)", 'os' => 'Homo sapiens'}
+  # * Bio::SPTR#os[0]['name'] -> "(Human)"
+  # * Bio::EPTR#os(0) -> "Homo sapiens (Human)"
+  # 
+  # === OS Line; organism species (>=1)
+  #  OS   Genus species (name).
+  #  OS   Genus species (name0) (name1).
+  #  OS   Genus species (name0) (name1).
+  #  OS   Genus species (name0), G s0 (name0), and G s (name0) (name1).
+  #  OS   Homo sapiens (Human), and Rarrus norveticus (Rat)
   def os(num = nil)
     unless @data['OS']
       os = Array.new
@@ -296,24 +342,26 @@ class SPTR < EMBLDB
   end
   
 
+  # Bio::EMBLDB::Common#og -> Array
   # OG Line; organella (0 or 1/entry)
   # ["MITOCHONDRION", "CHLOROPLAST", "Cyanelle", "Plasmid"]
   #  or a plasmid name (e.g. "Plasmid pBR322").  
-  #
-  # Bio::SPTR#og  -> Array
 
 
+  # Bio::EMBLDB::Common#oc -> Array
   # OC Line; organism classification (>=1)
-  # OC   Eukaryota; Alveolata; Apicomplexa; Piroplasmida; Theileriidae;
-  # OC   Theileria.
-  #
-  # Bio::EMBLDB#oc  -> Array
+  # "OC   Eukaryota; Alveolata; Apicomplexa; Piroplasmida; Theileriidae;"
+  # "OC   Theileria."
 
-  # OX Line; organism taxonomy cross-reference (>=1 per entry)
-  # OX   NCBI_TaxID=1234;
-  # OX   NCBI_TaxID=1234, 2345, 3456, 4567;
+
+
+  # returns a Hash of oraganism taxonomy cross-references.
+  # * Bio::SPTR#ox -> Hash
+  #    {'NCBI_TaxID' => ['1234','2345','3456','4567'], ...}
   #
-  # Bio::SPTR#ox -> {'NCBI_TaxID' => ['1234','2345','3456','4567']}
+  # === OX Line; organism taxonomy cross-reference (>=1 per entry)
+  #  OX   NCBI_TaxID=1234;
+  #  OX   NCBI_TaxID=1234, 2345, 3456, 4567;
   def ox
     unless @data['OX']
       tmp = fetch('OX').sub(/\.$/,'').split(/;/).map { |e| e.strip }
@@ -327,48 +375,57 @@ class SPTR < EMBLDB
     return @data['OX']
   end
 
-
+  
+  # Bio::EMBLDB::Common#ref -> Array
   # R Lines
   # RN RC RP RX RA RT RL
-  # Bio::EMBLDB#ref -> Array
 
-  # CC lines (>=0, optional)
-  # CC   -!- TISSUE SPECIFICITY: HIGHEST LEVELS FOUND IN TESTIS. ALSO PRESENT
-  # CC       IN LIVER, KIDNEY, LUNG AND BRAIN.
-  #
-  # CC   -!- TOPIC: FIRST LINE OF A COMMENT BLOCK;
-  # CC       SECOND AND SUBSEQUENT LINES OF A COMMENT BLOCK.
-  #
-  # CC   -!- CAUTION: HOGE HOGE IS FUGA FUGA!
-  #
 
   @@cc_topics = ['ALTERNATIVE PRODUCTS','CATALYTIC ACTIVITY','CAUTION',
     'COFACTOR','DATABASE','DEVELOPMENTAL STAGE','DISEASE','DOMAIN',
     'ENZYME REGULATION','FUNCTION','INDUCTION','MASS SPECTROMETRY',
     'MISCELLANEOUS','PATHWAY','PHARMACEUTICAL','POLYMORPHISM','PTM',
     'SIMILARITY','SUBCELLULAR LOCATION','SUBUNIT','TISSUE SPECIFICITY']
-
-  # DATABASE: NAME=Text[; NOTE=Text][; WWW="Address"][; FTP="Address"].
-  # MASS SPECTROMETRY: MW=XXX[; MW_ERR=XX][; METHOD=XX][;RANGE=XX-XX].
+  # returns contents in the CC lines.
+  # * Bio::SPTR#cc -> Hash
   #
-  # Bio::SPTR#cc -> Hash w/in Array
-  # Bio::SPTR#cc(Int) -> String
-  # Bio::SPTR#cc(TOPIC) -> Array w/in Hash
-  # Bio::SPTR#cc('ALTERNATIVE PRODUCTS') -> {'Event'=>str, 
-  #                                          'Named isoforms'=>int,
-  #                                          'Comment'=>str,
-  #                                          'Variants'=>[{'Name'=>str,
-  #                                                        'Synonyms'=>str,
-  #                                                        'IsoId'=>str,
-  #                                                        'Sequence'=>[]}]}
-  # Bio::SPTR#cc('DATABASE') -> [{'NAME'=>str,'NOTE'=>str,
-  #                               'WWW'=>URI,'FTP'=>URI}]
-  # Bio::SPTR#cc('MASS SPECTROMETRY') -> [{'MW"=>float,'MW_ERR'=>float,
-  #                                        'METHOD'=>str,'RANGE'=>str}]
+  # returns an object of contents in the TOPIC.
+  # * Bio::SPTR#cc(TOPIC) -> Array w/in Hash, Hash
+  #
+  # returns contents of the "ALTERNATIVE PRODUCTS".
+  # * Bio::SPTR#cc('ALTERNATIVE PRODUCTS') -> Hash
+  #    {'Event' => str, 
+  #     'Named isoforms' => int,  
+  #     'Comment' => str,
+  #     'Variants'=>[{'Name' => str, 'Synonyms' => str, 'IsoId' => str, 'Sequence' => []}]}
+  # 
+  #    CC   -!- ALTERNATIVE PRODUCTS:
+  #    CC       Event=Alternative splicing; Named isoforms=15;
+  #    ...
+  #    CC         placentae isoforms. All tissues differentially splice exon 13;
+  #    CC       Name=A; Synonyms=no del;
+  #    CC         IsoId=P15529-1; Sequence=Displayed;
+  #
+  # returns contents of the "DATABASE".
+  # * Bio::SPTR#cc('DATABASE') -> Array
+  #    [{'NAME'=>str,'NOTE'=>str, 'WWW'=>URI,'FTP'=>URI}, ...]
+  #
+  #    CC   -!- DATABASE: NAME=Text[; NOTE=Text][; WWW="Address"][; FTP="Address"].
+  #
+  # returns contents of the "MASS SPECTROMETRY".
+  # * Bio::SPTR#cc('MASS SPECTROMETRY') -> Array
+  #    [{'MW"=>float,'MW_ERR'=>float, 'METHOD'=>str,'RANGE'=>str}, ...]
+  #
+  #    CC   -!- MASS SPECTROMETRY: MW=XXX[; MW_ERR=XX][; METHOD=XX][;RANGE=XX-XX].
+  #
+  # === CC lines (>=0, optional)
+  #   CC   -!- TISSUE SPECIFICITY: HIGHEST LEVELS FOUND IN TESTIS. ALSO PRESENT
+  #   CC       IN LIVER, KIDNEY, LUNG AND BRAIN.
+  # 
+  #   CC   -!- TOPIC: FIRST LINE OF A COMMENT BLOCK;
+  #   CC       SECOND AND SUBSEQUENT LINES OF A COMMENT BLOCK.
   #
   def cc(tag = nil)
-
-    # @data['CC'] = {'DATABASE'=>['hoge','fuga'], ... }
     unless @data['CC']
       cc  = Hash.new
       cmt = '-' * (77 - 4 + 1)
@@ -404,19 +461,11 @@ class SPTR < EMBLDB
       @data['CC'] = cc
     end
 
-
     case tag
     when 'ALTERNATIVE PRODUCTS'
       ap = @data['CC']['ALTERNATIVE PRODUCTS'].to_s
       return ap unless ap
 
-      # CC   -!- ALTERNATIVE PRODUCTS:
-      # CC       Event=Alternative splicing; Named isoforms=15;
-      # ...
-      # CC         placentae isoforms. All tissues differentially splice exon 13;
-      # CC       Name=A; Synonyms=no del;
-      # CC         IsoId=P15529-1; Sequence=Displayed;
-
       # Event, Named isoforms, Comment, [Name, Synonyms, IsoId, Sequnce]+
       tmp = {'Event' => nil, 'Named isoforms' => nil, 'Comment' => nil, 'Variants'  => []}
 
@@ -483,8 +532,11 @@ class SPTR < EMBLDB
       end
       return tmp
 
+    when 'INTERACTION'
+      return cc_interaction_parse(@data['CC']['INTERACTION'].to_s)
+
     when nil
-      return @data['CC']	
+      return @data['CC']
 
     else
       return @data['CC'][tag]
@@ -492,6 +544,7 @@ class SPTR < EMBLDB
   end
 
 
+
   def cc_ap_variants_parse(ent)
     hsh = {}
     ent.split(/; /).map {|e| e.split(/=/) }.each do |e|
@@ -506,12 +559,25 @@ class SPTR < EMBLDB
   private :cc_ap_variants_parse
 
 
+  # returns conteins in a line of the CC INTERACTION section.
+  #
+  #   CC       P46527:CDKN1B; NbExp=1; IntAct=EBI-359815, EBI-519280;
+  def cc_interaction_parse(str)
+    it = str.scan(/(.+?); NbExp=(.+?); IntAct=(.+?);/)
+    it.map {|ent|
+      {:partner_id => ent[0].strip,
+       :nbexp => ent[1].strip, 
+       :intact_acc => ent[2].split(', ') }
+    }
+  end
+  private :cc_interaction_parse
 
-  # DR Line; defabases cross-reference (>=0)
-  # a cross_ref pre one line
-  # "DR  database_identifier; primary_identifier; secondary_identifier."
-  # Bio::EMBLDB#dr  -> Hash w/in Array
-
+  # returns databases cross-references in the DR lines.
+  # * Bio::EMBLDB#dr  -> Hash w/in Array
+  #
+  # === DR Line; defabases cross-reference (>=0)
+  #    DR  database_identifier; primary_identifier; secondary_identifier.
+  #  a cross_ref pre one line
   @@dr_database_identifier = ['EMBL','CARBBANK','DICTYDB','ECO2DBASE',
     'ECOGENE',
     'FLYBASE','GCRDB','HIV','HSC-2DPAGE','HSSP','INTERPRO','MAIZEDB',
@@ -519,27 +585,32 @@ class SPTR < EMBLDB
     'PROSITE','REBASE','AARHUS/GHENT-2DPAGE','SGD','STYGENE','SUBTILIST',
     'SWISS-2DPAGE','TIGR','TRANSFAC','TUBERCULIST','WORMPEP','YEPD','ZFIN']
 
-
+  # Bio::EMBLDB::Common#kw - Array
+  #                    #keywords  -> Array
+  #
   # KW Line; keyword (>=1)
   # KW   [Keyword;]+
-  # Bio::EMBLDB#kw  -> Array
-  #            #keywords  -> Array
 
-  # FT Line; feature table data (>=0, optional)
+
+  # returns conteins in the feature table.
+  # * Bio::SPTR#ft -> Hash
+  #    {'feature_name' => [{'From' => str, 'To' => str,
+  #                         'Description' => str, 'FTId' => str}],...}
   #
-  # Col     Data item
-  # -----   -----------------
-  #  1- 2   FT
-  #  6-13   Feature name 
-  # 15-20   `FROM' endpoint
-  # 22-27   `TO' endpoint
-  # 35-75   Description (>=0 per key)
-  # -----   -----------------
+  # returns an Array of the information about the feature_name in the feature table.
+  # * Bio::SPTR#ft(feature_name) -> Array of Hash
+  #    [{'From' => str, 'To' => str, 'Description' => str, 'FTId' => str},...]
   #
-  # Bio::SPTR#ft -> {'feature_name'=>[{'From'=>str,'To'=>str,
-  #                                    'Description'=>str, 'FTId'=>str}],}
-  # Bio::SPTR#ft(feature_name) -> [{'From'=>str,'To'=>str,
-  #                                 'Description'=>str, 'FTId'=>str},...]
+  # == FT Line; feature table data (>=0, optional)
+  #
+  #   Col     Data item
+  #   -----   -----------------
+  #    1- 2   FT
+  #    6-13   Feature name 
+  #   15-20   `FROM' endpoint
+  #   22-27   `TO' endpoint
+  #   35-75   Description (>=0 per key)
+  #   -----   -----------------
   def ft(feature_name = nil)
     unless @data['FT']
       table        = Hash.new()
@@ -634,16 +705,19 @@ class SPTR < EMBLDB
   end
 
 
-  # SQ Line; sequence header (1/entry)
-  # SQ   SEQUENCE   233 AA;  25630 MW;  146A1B48A1475C86 CRC64;
-  # SQ   SEQUENCE  \d+ AA; \d+ MW;  [0-9A-Z]+ CRC64;
+  # returns a Hash of conteins in the SQ lines.
+  # * Bio::SPTRL#sq  -> hsh
   #
-  # MW, Dalton unit
-  # CRC64 (64-bit Cyclic Redundancy Check, ISO 3309)
+  # returns a value of a key given in the SQ lines.
+  # * Bio::SPTRL#sq(key)  -> int or str
+  # * Keys: ['MW', 'mw', 'molecular', 'weight', 'aalen', 'len', 'length', 'CRC64']
   #
-  # Bio::SPTRL#sq  -> hsh
-  # Bio::SPTRL#sq(key)  -> int or str
+  # === SQ Line; sequence header (1/entry)
+  #    SQ   SEQUENCE   233 AA;  25630 MW;  146A1B48A1475C86 CRC64;
+  #    SQ   SEQUENCE  \d+ AA; \d+ MW;  [0-9A-Z]+ CRC64;
   #
+  # MW, Dalton unit.
+  # CRC64 (64-bit Cyclic Redundancy Check, ISO 3309).
   def sq(key = nil)
     unless @data['SQ']
       if fetch('SQ') =~ /(\d+) AA\; (\d+) MW; (.+) CRC64;/
@@ -667,10 +741,11 @@ class SPTR < EMBLDB
     end
   end
 
-  # @orig[''] as sequence
-  # blank Line; sequence data (>=1)
-  # Bio::SPTR#seq  -> Bio::Sequence::AA
+
+  # returns a Bio::Sequence::AA of the amino acid sequence.
+  # * Bio::SPTR#seq -> Bio::Sequence::AA
   #
+  # blank Line; sequence data (>=1)
   def seq
     unless @data['']
       @data[''] = Sequence::AA.new( fetch('').gsub(/ |\d+/,'') )
@@ -679,9 +754,9 @@ class SPTR < EMBLDB
   end
   alias aaseq seq
 
-end
+end # class SPTR
 
-end
+end # module Bio
 
 
 if __FILE__ == $0
@@ -690,8 +765,8 @@ if __FILE__ == $0
 
   begin
     require 'pp'
-    alias p pp
-  rescue LoadErrmr
+    alias pp p
+  rescue LoadError
   end
 
   def cmd(cmd, tag = nil, ent = $ent)
